summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/spl-transloc.cc
diff options
context:
space:
mode:
authorChris Campbell <chriscampbell89@gmail.com>2013-08-03 22:15:39 +0100
committerChris Campbell <chriscampbell89@gmail.com>2013-08-04 17:40:42 +0100
commit6315843d78dae55cbcd93669611fea4ae7e1637a (patch)
treeb8866535a1fe1d5da16f841ed1b8108b7cf96454 /crawl-ref/source/spl-transloc.cc
parent0add7a92c55bee439ab18ce930af678854a00242 (diff)
downloadcrawl-ref-6315843d78dae55cbcd93669611fea4ae7e1637a.tar.gz
crawl-ref-6315843d78dae55cbcd93669611fea4ae7e1637a.zip
Prevent orb apportation in Sprint
Since it turns out to be a good idea to apport the orb all the way across the map after clearing out earlier areas, if possible. This isn't so much the case in the regular game where Zot:5 enemies might still show up but maybe it'd be simpler/more consistent to just make the orb always apportation immune.
Diffstat (limited to 'crawl-ref/source/spl-transloc.cc')
-rw-r--r--crawl-ref/source/spl-transloc.cc8
1 files changed, 5 insertions, 3 deletions
diff --git a/crawl-ref/source/spl-transloc.cc b/crawl-ref/source/spl-transloc.cc
index 06f6e37ddc..b491540218 100644
--- a/crawl-ref/source/spl-transloc.cc
+++ b/crawl-ref/source/spl-transloc.cc
@@ -848,10 +848,12 @@ spret_type cast_apportation(int pow, bolt& beam, bool fail)
item_def& item = mitm[item_idx];
- // Can't apport the Orb in zotdef
- if (crawl_state.game_is_zotdef() && item_is_orb(item))
+ // Can't apport the Orb in zotdef or sprint
+ if (item_is_orb(item)
+ && (crawl_state.game_is_zotdef()
+ || crawl_state.game_is_sprint()))
{
- mpr("You cannot apport the sacred Orb!");
+ mpr("You cannot apport the Orb!");
return SPRET_ABORT;
}